@@ -1,10 +1,12 @@
 import sys
+from enum import IntEnum
 from hashlib import sha256
 from typing import Union
-
 from eth_typing import HexStr, Address, ChecksumAddress
 from eth_utils import remove_0x_prefix
 
+from zksync2.core.types import ADDRESS_DEFAULT, L2_ETH_TOKEN_ADDRESS
+
 
 def int_to_bytes(x: int) -> bytes:
     return x.to_bytes((x.bit_length() + 7) // 8, byteorder=sys.byteorder)
@@ -16,6 +18,10 @@ def to_bytes(data: Union[bytes, HexStr]) -> bytes:
     return bytes.fromhex(remove_0x_prefix(data))
 
 
+def is_eth(address: HexStr) -> bool:
+    return address.lower() == ADDRESS_DEFAULT or address.lower() == L2_ETH_TOKEN_ADDRESS
+
+
 def encode_address(addr: Union[Address, ChecksumAddress, str]) -> bytes:
     if len(addr) == 0:
         return bytes()
@@ -40,3 +46,9 @@ def hash_byte_code(bytecode: bytes) -> bytes:
 def pad_front_bytes(bs: bytes, needed_length: int):
     padded = b'\0' * (needed_length - len(bs)) + bs
     return padded
+
+
+class RecommendedGasLimit(IntEnum):
+    DEPOSIT = 600000
+    EXECUTE = 620000
+    ERC20_APPROVE = 50000
