@@ -2,10 +2,8 @@ import importlib.resources as pkg_resources
 from web3 import Web3
 from eth_typing import HexStr
 import json
-
-from web3.module import Module
-
 from zksync2.manage_contracts import contract_abi
+from zksync2.manage_contracts.contract_encoder_base import BaseContractEncoder
 
 paymaster_flow_abi_cache = None
 
@@ -21,14 +19,13 @@ def _paymaster_flow_abi_default():
     return paymaster_flow_abi_cache
 
 
-class PaymasterFlowEncoder:
+class PaymasterFlowEncoder(BaseContractEncoder):
 
-    def __init__(self, module: Module):
-        self.contract = module.contract(address=None,
-                                        abi=_paymaster_flow_abi_default())
+    def __init__(self, web3: Web3):
+        super(PaymasterFlowEncoder, self).__init__(web3, abi=_paymaster_flow_abi_default())
 
     def encode_approval_based(self, address: HexStr, min_allowance: int, inner_input: bytes) -> HexStr:
-        return self.contract.encodeABI(fn_name="approvalBased", args=[address, min_allowance, inner_input])
+        return self.encode_method(fn_name="approvalBased", args=[address, min_allowance, inner_input])
 
-    def encode_general(self, inputs: bytes):
-        return self.contract.encodeABI(fn_name="general", args=[inputs])
+    def encode_general(self, inputs: bytes) -> HexStr:
+        return self.encode_method(fn_name="general", args=[inputs])
